@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use base qw/Import::Export/;
 
@@ -28,7 +28,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -113,12 +113,13 @@ The third function exported by this module is unmake_readonly. It will take a pe
 
 The fourth function exported by this module is is_readonly. It will deeply check a reference to see if it is readonly.
 
-	my $string = "abc";
-	is_readonly($string); # 0;
-	make_readonly($string);
-	is_readonly($string); # 1;
-	
+	my $ref = { one => "abc" };
+	is_readonly($ref); # 0;
+	make_readonly($ref);
+	is_readonly($ref); # 1;
 
+NOTE: this function fails to validate make_readonly scalar variables I am currently unsure why.
+	
 =head2 BENCHMARK
 
 	use Benchmark qw(:all);
